/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.java.net
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.windows;

import it.tidalwave.netbeans.windows.role.TopComponentRole;
import java.util.ArrayList;
import java.util.List;
import org.junit.Before;
import org.junit.Test;
import static org.mockito.Mockito.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class EnhancedTopComponentTest
  {
    private EnhancedTopComponent fixture;
    private List<TopComponentRole> topComponentRoles = new ArrayList<TopComponentRole>();

    @Before
    public void setUp() 
      {
        fixture = new EnhancedTopComponent()
          {
            @Override
            public String preferredID()
              {
                return "xx";
              }
          };

        for (int i = 0; i < 10; i++)
          {
            final TopComponentRole role = mock(TopComponentRole.class);
            topComponentRoles.add(role);
            fixture.addRole(role);
          }
      }

    // TODO: should test initialization and call of @PostConstructor

    @Test
    public void shouldNotifyActivated()
      {
        fixture.componentActivated();

        for (final TopComponentRole topComponentRole : topComponentRoles)
          {
            verify(topComponentRole).notifyActivated();
          }
      }

    @Test
    public void shouldNotifyDectivated()
      {
        fixture.componentDeactivated();

        for (final TopComponentRole topComponentRole : topComponentRoles)
          {
            verify(topComponentRole).notifyDeactivated();
          }
      }

    @Test
    public void shouldNotifyOpened()
      {
        fixture.componentOpened();

        for (final TopComponentRole topComponentRole : topComponentRoles)
          {
            verify(topComponentRole).notifyOpened();
          }
      }

    @Test
    public void shouldNotifyClosed()
      {
        fixture.componentClosed();

        for (final TopComponentRole topComponentRole : topComponentRoles)
          {
            verify(topComponentRole).notifyClosed();
          }
      }

    @Test
    public void shouldNotifyShowing()
      {
        fixture.componentShowing();

        for (final TopComponentRole topComponentRole : topComponentRoles)
          {
            verify(topComponentRole).notifyShowing();
          }
      }

    @Test
    public void shouldNotifyHidden()
      {
        fixture.componentHidden();

        for (final TopComponentRole topComponentRole : topComponentRoles)
          {
            verify(topComponentRole).notifyHidden();
          }
      }
  }