/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.java.net
 * SCM: https://bitbucket.org/tidalwave/openbluesky-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.windows.role;

import java.awt.EventQueue;
import org.openide.util.lookup.Lookups;
import org.openide.explorer.ExplorerManager;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.windows.TopComponent;
import org.netbeans.platformx.inject.api.Injector;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;
import static org.hamcrest.CoreMatchers.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class NodeActivatorTest
  {
    private TopComponent topComponent;
    private ExplorerManager explorerManager;
    private NodeActivator fixture;

    @Before
    public void setup()
      {
        topComponent = new TopComponent(); // can't mock setActivatedNodes() as it is private
        explorerManager = new ExplorerManager();
        fixture = new NodeActivator();
      }

    @Test
    public void shouldCallSetActivatedNodesOnSelectionChange()
      throws Exception
      {
        Injector.getDefault().inject(fixture, Lookups.fixed(topComponent, explorerManager));

        final Node[] nodes = new Node[] { new AbstractNode(Children.LEAF) };
        explorerManager.setRootContext(nodes[0]);
        assertThat(topComponent.getActivatedNodes(), is(nullValue()));

        explorerManager.setSelectedNodes(nodes);

        // Events are delivered in the EDT, so wait for the queue to be flushed
        EventQueue.invokeAndWait(new Runnable()
          {
            @Override
            public void run()
              {
              }
          });

        assertThat(topComponent.getActivatedNodes(), is(nodes));
      }
  }
